const ALLOW_EMPTY_CLASS = 0x00000001 % UInt32
const ALT_BSUX = 0x00000002 % UInt32
const ALT_CIRCUMFLEX = 0x00200000 % UInt32
const ALT_VERBNAMES = 0x00400000 % UInt32
const ANCHORED = 0x80000000 % UInt32
const AUTO_CALLOUT = 0x00000004 % UInt32
const BSR_ANYCRLF = 2 % UInt32
const BSR_UNICODE = 1 % UInt32
const CALLOUT_BACKTRACK = 0x00000002 % UInt32
const CALLOUT_STARTMATCH = 0x00000001 % UInt32
const CASELESS = 0x00000008 % UInt32
const CODE_UNIT_WIDTH = 8 % UInt32
const CONFIG_BSR = 0 % UInt32
const CONFIG_COMPILED_WIDTHS = 14 % UInt32
const CONFIG_DEPTHLIMIT = 7 % UInt32
const CONFIG_HEAPLIMIT = 12 % UInt32
const CONFIG_JIT = 1 % UInt32
const CONFIG_JITTARGET = 2 % UInt32
const CONFIG_LINKSIZE = 3 % UInt32
const CONFIG_MATCHLIMIT = 4 % UInt32
const CONFIG_NEVER_BACKSLASH_C = 13 % UInt32
const CONFIG_NEWLINE = 5 % UInt32
const CONFIG_PARENSLIMIT = 6 % UInt32
const CONFIG_RECURSIONLIMIT = 7 % UInt32
const CONFIG_STACKRECURSE = 8 % UInt32
const CONFIG_UNICODE = 9 % UInt32
const CONFIG_UNICODE_VERSION = 10 % UInt32
const CONFIG_VERSION = 11 % UInt32
const CONVERT_GLOB = 0x00000010 % UInt32
const CONVERT_GLOB_NO_STARSTAR = 0x00000050 % UInt32
const CONVERT_GLOB_NO_WILD_SEPARATOR = 0x00000030 % UInt32
const CONVERT_NO_UTF_CHECK = 0x00000002 % UInt32
const CONVERT_POSIX_BASIC = 0x00000004 % UInt32
const CONVERT_POSIX_EXTENDED = 0x00000008 % UInt32
const CONVERT_UTF = 0x00000001 % UInt32
const COPY_MATCHED_SUBJECT = 0x00004000 % UInt32
const DFA_RESTART = 0x00000040 % UInt32
const DFA_SHORTEST = 0x00000080 % UInt32
const DOLLAR_ENDONLY = 0x00000010 % UInt32
const DOTALL = 0x00000020 % UInt32
const DUPNAMES = 0x00000040 % UInt32
const ENDANCHORED = 0x20000000 % UInt32
const ERROR_ALPHA_ASSERTION_UNKNOWN = 195 % UInt32
const ERROR_BACKSLASH_C_CALLER_DISABLED = 183 % UInt32
const ERROR_BACKSLASH_C_LIBRARY_DISABLED = 185 % UInt32
const ERROR_BACKSLASH_C_SYNTAX = 168 % UInt32
const ERROR_BACKSLASH_G_SYNTAX = 157 % UInt32
const ERROR_BACKSLASH_K_SYNTAX = 169 % UInt32
const ERROR_BACKSLASH_N_IN_CLASS = 171 % UInt32
const ERROR_BACKSLASH_O_MISSING_BRACE = 155 % UInt32
const ERROR_BACKSLASH_U_CODE_POINT_TOO_BIG = 177 % UInt32
const ERROR_BADDATA = (-29) % UInt32
const ERROR_BADMAGIC = (-31) % UInt32
const ERROR_BADMODE = (-32) % UInt32
const ERROR_BADOFFSET = (-33) % UInt32
const ERROR_BADOFFSETLIMIT = (-56) % UInt32
const ERROR_BADOPTION = (-34) % UInt32
const ERROR_BADREPESCAPE = (-57) % UInt32
const ERROR_BADREPLACEMENT = (-35) % UInt32
const ERROR_BADSERIALIZEDDATA = (-62) % UInt32
const ERROR_BADSUBSPATTERN = (-60) % UInt32
const ERROR_BADSUBSTITUTION = (-59) % UInt32
const ERROR_BADUTFOFFSET = (-36) % UInt32
const ERROR_BAD_LITERAL_OPTIONS = 192 % UInt32
const ERROR_BAD_OPTIONS = 117 % UInt32
const ERROR_BAD_RELATIVE_REFERENCE = 129 % UInt32
const ERROR_BAD_SUBPATTERN_REFERENCE = 115 % UInt32
const ERROR_CALLOUT = (-37) % UInt32
const ERROR_CALLOUT_BAD_STRING_DELIMITER = 182 % UInt32
const ERROR_CALLOUT_NO_STRING_DELIMITER = 181 % UInt32
const ERROR_CALLOUT_NUMBER_TOO_BIG = 138 % UInt32
const ERROR_CALLOUT_STRING_TOO_LONG = 172 % UInt32
const ERROR_CLASS_INVALID_RANGE = 150 % UInt32
const ERROR_CLASS_RANGE_ORDER = 108 % UInt32
const ERROR_CODE_POINT_TOO_BIG = 134 % UInt32
const ERROR_CONDITION_ASSERTION_EXPECTED = 128 % UInt32
const ERROR_CONDITION_ATOMIC_ASSERTION_EXPECTED = 198 % UInt32
const ERROR_CONVERT_SYNTAX = (-64) % UInt32
const ERROR_DEFINE_TOO_MANY_BRANCHES = 154 % UInt32
const ERROR_DEPTHLIMIT = (-53) % UInt32
const ERROR_DFA_BADRESTART = (-38) % UInt32
const ERROR_DFA_RECURSE = (-39) % UInt32
const ERROR_DFA_UCOND = (-40) % UInt32
const ERROR_DFA_UFUNC = (-41) % UInt32
const ERROR_DFA_UINVALID_UTF = (-66) % UInt32
const ERROR_DFA_UITEM = (-42) % UInt32
const ERROR_DFA_WSSIZE = (-43) % UInt32
const ERROR_DUPLICATE_SUBPATTERN_NAME = 143 % UInt32
const ERROR_END_BACKSLASH = 101 % UInt32
const ERROR_END_BACKSLASH_C = 102 % UInt32
const ERROR_ESCAPE_INVALID_IN_CLASS = 107 % UInt32
const ERROR_ESCAPE_INVALID_IN_VERB = 140 % UInt32
const ERROR_HEAPLIMIT = (-63) % UInt32
const ERROR_HEAP_FAILED = 121 % UInt32
const ERROR_INTERNAL = (-44) % UInt32
const ERROR_INTERNAL_BAD_CODE = 189 % UInt32
const ERROR_INTERNAL_BAD_CODE_AUTO_POSSESS = 180 % UInt32
const ERROR_INTERNAL_BAD_CODE_IN_SKIP = 190 % UInt32
const ERROR_INTERNAL_BAD_CODE_LOOKBEHINDS = 170 % UInt32
const ERROR_INTERNAL_CODE_OVERFLOW = 123 % UInt32
const ERROR_INTERNAL_DUPMATCH = (-65) % UInt32
const ERROR_INTERNAL_MISSING_SUBPATTERN = 153 % UInt32
const ERROR_INTERNAL_OVERRAN_WORKSPACE = 152 % UInt32
const ERROR_INTERNAL_PARSED_OVERFLOW = 163 % UInt32
const ERROR_INTERNAL_STUDY_ERROR = 131 % UInt32
const ERROR_INTERNAL_UNEXPECTED_REPEAT = 110 % UInt32
const ERROR_INTERNAL_UNKNOWN_NEWLINE = 156 % UInt32
const ERROR_INVALID_AFTER_PARENS_QUERY = 111 % UInt32
const ERROR_INVALID_HEXADECIMAL = 167 % UInt32
const ERROR_INVALID_HYPHEN_IN_OPTIONS = 194 % UInt32
const ERROR_INVALID_OCTAL = 164 % UInt32
const ERROR_INVALID_SUBPATTERN_NAME = 144 % UInt32
const ERROR_JIT_BADOPTION = (-45) % UInt32
const ERROR_JIT_STACKLIMIT = (-46) % UInt32
const ERROR_LOOKBEHIND_INVALID_BACKSLASH_C = 136 % UInt32
const ERROR_LOOKBEHIND_NOT_FIXED_LENGTH = 125 % UInt32
const ERROR_LOOKBEHIND_TOO_COMPLICATED = 135 % UInt32
const ERROR_LOOKBEHIND_TOO_LONG = 187 % UInt32
const ERROR_MALFORMED_UNICODE_PROPERTY = 146 % UInt32
const ERROR_MARK_MISSING_ARGUMENT = 166 % UInt32
const ERROR_MATCHLIMIT = (-47) % UInt32
const ERROR_MISSING_CALLOUT_CLOSING = 139 % UInt32
const ERROR_MISSING_CLOSING_PARENTHESIS = 114 % UInt32
const ERROR_MISSING_COMMENT_CLOSING = 118 % UInt32
const ERROR_MISSING_CONDITION_CLOSING = 124 % UInt32
const ERROR_MISSING_NAME_TERMINATOR = 142 % UInt32
const ERROR_MISSING_OCTAL_OR_HEX_DIGITS = 178 % UInt32
const ERROR_MISSING_SQUARE_BRACKET = 106 % UInt32
const ERROR_MIXEDTABLES = (-30) % UInt32
const ERROR_NOMATCH = (-1) % UInt32
const ERROR_NOMEMORY = (-48) % UInt32
const ERROR_NOSUBSTRING = (-49) % UInt32
const ERROR_NOUNIQUESUBSTRING = (-50) % UInt32
const ERROR_NO_SURROGATES_IN_UTF16 = 191 % UInt32
const ERROR_NULL = (-51) % UInt32
const ERROR_NULL_PATTERN = 116 % UInt32
const ERROR_OCTAL_BYTE_TOO_BIG = 151 % UInt32
const ERROR_PARENS_QUERY_R_MISSING_CLOSING = 158 % UInt32
const ERROR_PARENTHESES_NEST_TOO_DEEP = 119 % UInt32
const ERROR_PARENTHESES_STACK_CHECK = 133 % UInt32
const ERROR_PARTIAL = (-2) % UInt32
const ERROR_PATTERN_STRING_TOO_LONG = 188 % UInt32
const ERROR_PATTERN_TOO_COMPLICATED = 186 % UInt32
const ERROR_PATTERN_TOO_LARGE = 120 % UInt32
const ERROR_POSIX_CLASS_NOT_IN_CLASS = 112 % UInt32
const ERROR_POSIX_NO_SUPPORT_COLLATING = 113 % UInt32
const ERROR_QUANTIFIER_INVALID = 109 % UInt32
const ERROR_QUANTIFIER_OUT_OF_ORDER = 104 % UInt32
const ERROR_QUANTIFIER_TOO_BIG = 105 % UInt32
const ERROR_QUERY_BARJX_NEST_TOO_DEEP = 184 % UInt32
const ERROR_RECURSELOOP = (-52) % UInt32
const ERROR_RECURSIONLIMIT = (-53) % UInt32
const ERROR_REPMISSINGBRACE = (-58) % UInt32
const ERROR_SCRIPT_RUN_NOT_AVAILABLE = 196 % UInt32
const ERROR_SUBPATTERN_NAMES_MISMATCH = 165 % UInt32
const ERROR_SUBPATTERN_NAME_EXPECTED = 162 % UInt32
const ERROR_SUBPATTERN_NAME_TOO_LONG = 148 % UInt32
const ERROR_SUBPATTERN_NUMBER_TOO_BIG = 161 % UInt32
const ERROR_SUPPORTED_ONLY_IN_UNICODE = 193 % UInt32
const ERROR_TOOMANYREPLACE = (-61) % UInt32
const ERROR_TOO_MANY_CAPTURES = 197 % UInt32
const ERROR_TOO_MANY_CONDITION_BRANCHES = 127 % UInt32
const ERROR_TOO_MANY_NAMED_SUBPATTERNS = 149 % UInt32
const ERROR_UCP_IS_DISABLED = 175 % UInt32
const ERROR_UNAVAILABLE = (-54) % UInt32
const ERROR_UNICODE_DISALLOWED_CODE_POINT = 173 % UInt32
const ERROR_UNICODE_NOT_SUPPORTED = 132 % UInt32
const ERROR_UNICODE_PROPERTIES_UNAVAILABLE = 145 % UInt32
const ERROR_UNKNOWN_ESCAPE = 103 % UInt32
const ERROR_UNKNOWN_POSIX_CLASS = 130 % UInt32
const ERROR_UNKNOWN_UNICODE_PROPERTY = 147 % UInt32
const ERROR_UNMATCHED_CLOSING_PARENTHESIS = 122 % UInt32
const ERROR_UNRECOGNIZED_AFTER_QUERY_P = 141 % UInt32
const ERROR_UNSET = (-55) % UInt32
const ERROR_UNSUPPORTED_ESCAPE_SEQUENCE = 137 % UInt32
const ERROR_UTF16_ERR1 = (-24) % UInt32
const ERROR_UTF16_ERR2 = (-25) % UInt32
const ERROR_UTF16_ERR3 = (-26) % UInt32
const ERROR_UTF32_ERR1 = (-27) % UInt32
const ERROR_UTF32_ERR2 = (-28) % UInt32
const ERROR_UTF8_ERR1 = (-3) % UInt32
const ERROR_UTF8_ERR10 = (-12) % UInt32
const ERROR_UTF8_ERR11 = (-13) % UInt32
const ERROR_UTF8_ERR12 = (-14) % UInt32
const ERROR_UTF8_ERR13 = (-15) % UInt32
const ERROR_UTF8_ERR14 = (-16) % UInt32
const ERROR_UTF8_ERR15 = (-17) % UInt32
const ERROR_UTF8_ERR16 = (-18) % UInt32
const ERROR_UTF8_ERR17 = (-19) % UInt32
const ERROR_UTF8_ERR18 = (-20) % UInt32
const ERROR_UTF8_ERR19 = (-21) % UInt32
const ERROR_UTF8_ERR2 = (-4) % UInt32
const ERROR_UTF8_ERR20 = (-22) % UInt32
const ERROR_UTF8_ERR21 = (-23) % UInt32
const ERROR_UTF8_ERR3 = (-5) % UInt32
const ERROR_UTF8_ERR4 = (-6) % UInt32
const ERROR_UTF8_ERR5 = (-7) % UInt32
const ERROR_UTF8_ERR6 = (-8) % UInt32
const ERROR_UTF8_ERR7 = (-9) % UInt32
const ERROR_UTF8_ERR8 = (-10) % UInt32
const ERROR_UTF8_ERR9 = (-11) % UInt32
const ERROR_UTF_IS_DISABLED = 174 % UInt32
const ERROR_VERB_ARGUMENT_NOT_ALLOWED = 159 % UInt32
const ERROR_VERB_NAME_TOO_LONG = 176 % UInt32
const ERROR_VERB_UNKNOWN = 160 % UInt32
const ERROR_VERSION_CONDITION_SYNTAX = 179 % UInt32
const ERROR_ZERO_RELATIVE_REFERENCE = 126 % UInt32
const EXTENDED = 0x00000080 % UInt32
const EXTENDED_MORE = 0x01000000 % UInt32
const EXTRA_ALLOW_SURROGATE_ESCAPES = 0x00000001 % UInt32
const EXTRA_ALT_BSUX = 0x00000020 % UInt32
const EXTRA_BAD_ESCAPE_IS_LITERAL = 0x00000002 % UInt32
const EXTRA_ESCAPED_CR_IS_LF = 0x00000010 % UInt32
const EXTRA_MATCH_LINE = 0x00000008 % UInt32
const EXTRA_MATCH_WORD = 0x00000004 % UInt32
const FIRSTLINE = 0x00000100 % UInt32
const INFO_ALLOPTIONS = 0 % UInt32
const INFO_ARGOPTIONS = 1 % UInt32
const INFO_BACKREFMAX = 2 % UInt32
const INFO_BSR = 3 % UInt32
const INFO_CAPTURECOUNT = 4 % UInt32
const INFO_DEPTHLIMIT = 21 % UInt32
const INFO_EXTRAOPTIONS = 26 % UInt32
const INFO_FIRSTBITMAP = 7 % UInt32
const INFO_FIRSTCODETYPE = 6 % UInt32
const INFO_FIRSTCODEUNIT = 5 % UInt32
const INFO_FRAMESIZE = 24 % UInt32
const INFO_HASBACKSLASHC = 23 % UInt32
const INFO_HASCRORLF = 8 % UInt32
const INFO_HEAPLIMIT = 25 % UInt32
const INFO_JCHANGED = 9 % UInt32
const INFO_JITSIZE = 10 % UInt32
const INFO_LASTCODETYPE = 12 % UInt32
const INFO_LASTCODEUNIT = 11 % UInt32
const INFO_MATCHEMPTY = 13 % UInt32
const INFO_MATCHLIMIT = 14 % UInt32
const INFO_MAXLOOKBEHIND = 15 % UInt32
const INFO_MINLENGTH = 16 % UInt32
const INFO_NAMECOUNT = 17 % UInt32
const INFO_NAMEENTRYSIZE = 18 % UInt32
const INFO_NAMETABLE = 19 % UInt32
const INFO_NEWLINE = 20 % UInt32
const INFO_RECURSIONLIMIT = 21 % UInt32
const INFO_SIZE = 22 % UInt32
const JIT_COMPLETE = 0x00000001 % UInt32
const JIT_INVALID_UTF = 0x00000100 % UInt32
const JIT_PARTIAL_HARD = 0x00000004 % UInt32
const JIT_PARTIAL_SOFT = 0x00000002 % UInt32
const LITERAL = 0x02000000 % UInt32
const MAJOR = 10 % UInt32
const MATCH_INVALID_UTF = 0x04000000 % UInt32
const MATCH_UNSET_BACKREF = 0x00000200 % UInt32
const MINOR = 34 % UInt32
const MULTILINE = 0x00000400 % UInt32
const NEVER_BACKSLASH_C = 0x00100000 % UInt32
const NEVER_UCP = 0x00000800 % UInt32
const NEVER_UTF = 0x00001000 % UInt32
const NEWLINE_ANY = 4 % UInt32
const NEWLINE_ANYCRLF = 5 % UInt32
const NEWLINE_CR = 1 % UInt32
const NEWLINE_CRLF = 3 % UInt32
const NEWLINE_LF = 2 % UInt32
const NEWLINE_NUL = 6 % UInt32
const NOTBOL = 0x00000001 % UInt32
const NOTEMPTY = 0x00000004 % UInt32
const NOTEMPTY_ATSTART = 0x00000008 % UInt32
const NOTEOL = 0x00000002 % UInt32
const NO_AUTO_CAPTURE = 0x00002000 % UInt32
const NO_AUTO_POSSESS = 0x00004000 % UInt32
const NO_DOTSTAR_ANCHOR = 0x00008000 % UInt32
const NO_JIT = 0x00002000 % UInt32
const NO_START_OPTIMIZE = 0x00010000 % UInt32
const NO_UTF_CHECK = 0x40000000 % UInt32
const PARTIAL_HARD = 0x00000020 % UInt32
const PARTIAL_SOFT = 0x00000010 % UInt32
const SUBSTITUTE_EXTENDED = 0x00000200 % UInt32
const SUBSTITUTE_GLOBAL = 0x00000100 % UInt32
const SUBSTITUTE_OVERFLOW_LENGTH = 0x00001000 % UInt32
const SUBSTITUTE_UNKNOWN_UNSET = 0x00000800 % UInt32
const SUBSTITUTE_UNSET_EMPTY = 0x00000400 % UInt32
const UCP = 0x00020000 % UInt32
const UNGREEDY = 0x00040000 % UInt32
const USE_OFFSET_LIMIT = 0x00800000 % UInt32
const UTF = 0x00080000 % UInt32
